/* 
**  mod_kitchensink.c -- Apache Kitchen Sink module
**
**  To play with this sample module first compile it into a
**  DSO file and install it into Apache's modules directory 
**  by running:
**
**    $ apxs -c -i mod_kitchensink.c
**
**  Then activate it in Apache's httpd2.conf file for instance
**  for the URL /kitchensink in as follows:
**
**    #   httpd2.conf
**    LoadModule kitchensink_module modules/mod_kitchensink.so
**    <Location /kitchensink>
**    SetHandler kitchensink
**    </Location>
**
**  Then after restarting Apache via
**
**    $ apachectl restart
**
**  you immediately can request the URL /kitchensink and watch for the
**  output of this module. This can be achieved for instance via:
**
**    $ lynx http://localhost/kitchensink 
**
*/ 

#include "httpd.h"
#include "http_config.h"
#include "http_protocol.h"
#include "ap_config.h"
#include "sink.h"

/* kitchensink content handler */
static int kitchensink_handler(request_rec *r)
{
    int i;
    if (strcmp(r->handler, "kitchensink")) {
        return DECLINED;
    }
    r->content_type = "image/jpeg";      

    if (!r->header_only)
        for(i=0;i<=sizeof(sink);i++) {
          ap_rputc(sink[i], r);
        }
    return OK;

/* In case we want to redirect to a URL instead...
	apr_table_setn (r->headers_out, "Location", "http://www.advx.org");

	return HTTP_MOVED_TEMPORARILY;
*/

}

/** Add kitchensink version */
static int kitchensink_init_handler(apr_pool_t * p, apr_pool_t * plog,
				  apr_pool_t * ptemp, server_rec * s)
{
    ap_add_version_component(p, "KitchenSink/" "1.0");
    return OK;
}

static void kitchensink_register_hooks(apr_pool_t *p)
{
    ap_hook_handler(kitchensink_handler, NULL, NULL, APR_HOOK_MIDDLE);
    ap_hook_post_config(kitchensink_init_handler, NULL, NULL, APR_HOOK_MIDDLE);
}

/* Dispatch list for API hooks */
module AP_MODULE_DECLARE_DATA kitchensink_module = {
    STANDARD20_MODULE_STUFF, 
    NULL,                  /* create per-dir    config structures */
    NULL,                  /* merge  per-dir    config structures */
    NULL,                  /* create per-server config structures */
    NULL,                  /* merge  per-server config structures */
    NULL,                  /* table of config file commands       */
    kitchensink_register_hooks  /* register hooks                      */
};

